from flask_httpauth import HTTPBasicAuth
from werkzeug.security import generate_password_hash, check_password_hash

from pkg_trainmote.databaseControllerModule import DatabaseController

auth = HTTPBasicAuth()

@auth.verify_password
def verify_password(username, password):
    users = DatabaseController().getUsers()
    print(users)
    print(next(u for u in users if u.username == username and check_password_hash(u.password, password)))
    return next(u for u in users if u.username == username and check_password_hash(u.password, password))

@auth.get_user_roles
def get_user_roles(user):
    print(user)
    return user.roles



import RPi.GPIO as GPIO
import time
import threading
from . import deviceController

class PowerThread(threading.Thread):

    def __init__(self, pin: int):
        threading.Thread.__init__(self)
        self.isTurningOff = False
        self.kill = threading.Event()
        self.pin = pin
        GPIO.setup(pin, GPIO.IN)

    def run(self):
        self.trackVoltage()

    def stop(self):
        self.kill.set()

    def trackVoltage(self):
        while not self.isTurningOff and not self.kill.is_set():
            if GPIO.input(self.pin):
                self.isTurningOff = True
                deviceController.shutdown()
            else:
                time.sleep(0.5)



import RPi.GPIO as GPIO
import threading
import time

STATE_NOT_CONNECTED = "BLUETOOTH_NOT_CONNECTED"
STATE_CONNECTED = "BLUETOOTH_CONNECTED"
STATE_SHUTDOWN = "SHUTDOWN_IN_PROCESS"

class StateController:

    stateThread = None

    def __init__(self, pin: int):
        GPIO.setup(pin, GPIO.OUT)
        self.statePin = pin

    def setState(self, stateName):
        print("Changing Thread")
        self.stop()
        print("Create New State Thread")
        self.stateThread = StateThread(stateName, self.statePin)
        self.stateThread.start()

    def stop(self):
        if self.stateThread is not None:
            print("Kill Thread")
            self.stateThread.kill.set()
            self.stateThread.turnOff()
            self.stateThread.join()


class StateThread(threading.Thread):

    currentState = ""

    def __init__(self, state, pin: int):
        threading.Thread.__init__(self)
        self.currentState = state
        self.kill = threading.Event()
        self.pin = pin

    def run(self):
        if self.currentState == STATE_NOT_CONNECTED:
            self.blink(1)
        elif self.currentState == STATE_CONNECTED:
            self.turnOn()
        elif self.currentState == STATE_SHUTDOWN:
            self.blink(0.2)
        else:
            self.turnOff()

    def blink(self, blinkTime):
        isOn = False
        while not self.kill.is_set():
            if isOn:
                self.turnOff()
            else:
                self.turnOn()
            isOn = not isOn
            time.sleep(blinkTime)

    def turnOff(self):
        GPIO.output(self.pin, GPIO.HIGH)

    def turnOn(self):
        GPIO.output(self.pin, GPIO.LOW)



from typing import Optional

class User():

    def __init__(
        self,
        uid: str,
        username: str,
        password: int,
        roles: Optional[str]
    ):
        self.uid = uid
        self.username = username
        self.password = password
        self.roles = roles

    def to_dict(self):
        return {
            "uid": self.uid,
            "username": self.username,
            "password": self.password,
            "roles": self.roles
        }